/* -*- Mode: C; tab-width: 2; indent-tabs-mode: t; c-basic-offset: 2 -*- */
/* Copyright (C) 2001 The Free Software Foundation
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 *
 * Authors: Ante Brkic <abrkic@linux.hr>
 *          Arturo Espinosa <arturo@ximian.com> (team codes and minor bugs).
 *          Dario Lah <dlah@foi.hr>
 */

#ifndef _SI3D_H_
#define _SI3D_H_ 1

#include <stdio.h>
#include <stdlib.h>
#include <stdarg.h>
#include <string.h>
#include <math.h>
#include <time.h>
#include <allegro.h>

#ifndef MSVC
#ifdef DEBUG  /*debug*/
#include <mcheck.h>
#define debug_message(message) \
      ({char *msg = (message); printf("%s:%s:%i: %s\n", __FILE__, \
              __PRETTY_FUNCTION__, __LINE__, msg);})
#else
#define debug_message(message)({});
#endif /*debug */
#else
void debug_message (char *msg);
#endif

#define MAX_BROJ_VRHOVA      20
#define MAX_VISINA_VRHA      200
#define BROJ_VRHOVA          3
#define SIRINA_VRHA          30
#define SIRINA_BRDA          70
#define NEW_GAME             1
#define LOAD                 2
#define OPTIONS              3
#define CREDITS              4
#define EXIT                 5
#if !defined(PI)
#define PI                   (float)3.1415
#endif

#define KILL 1
#define DIE 2
#define MAX_MESSAGE_SIZE 100
#define SLEEP_TIME	2000	/* mill. sec. */

char *talk_buffer_kill;
char *talk_buffer_die;
int talk_kill_count;
int talk_die_count;
int talk_buffer_kill_size;
int talk_buffer_die_size;

void init_talk();
void talk(int what, int who);

struct
{
	short int vis;
	short int sjena;
} reljef[640][640];
struct
{
	short int r, g, b;
} kopno[100][100];
struct
{
	short int r, g, b;
} more[50][50];
struct
{
	short int r[20][20], g[20][20], b[20][20];
} tekstura_tenka[7];
typedef struct
{
	int broj;
  int flag;
	double x, y, z;
	double kut;
	double kut_cijevi;
	double x_projektil, y_projektil, z_projektil;
	double x_pomak, y_pomak, z_pomak;
	int r, g, b;
	char *ime;
	int energija, stit, ap;
	double mp;
	int *w;
	int aktivno_oruzje;
	int broj_pobjeda;
	double ukupna_steta;
	int mrtav;
} Tenk;

Tenk tenk[128];

struct
{
	int trosi_ap;
	int radijus;
	double jacina;
} oruzje[11];

struct
{
	short int vrsta;
	int x, y;
	short int oruzje;
} poklon[100];

char *datafile_name;
BITMAP *monitor;
BITMAP *za_monitor;
BITMAP *pogled;
BITMAP *suc;
BITMAP *slika_suc;
BITMAP *aktivni;
DATAFILE *graphics, *fire, *explosion, *background;
int have_sound;
int play_sound;
int boja_fonta;
int broj_pogleda;
int sirina_teksture_kopna;
int visina_teksture_kopna;
int sirina_teksture_mora;
int visina_teksture_mora;
double kut_svjetlosti;
int igrac;
int broj_igraca;
int broj_teams;
int broj_team_size;
int nivo;
int vidljivo_sucelje;
int broj_runde;
int max_broj_rundi;
int broj_turna;
int broj_poklona;
int kontrola;
int r[256], g[256], b[256];
/*char small_health[450];
char big_health[800];
char shield[480];
char ap[288], mp[288];
char weapon[800];*/
BITMAP *small_health, *big_health, *shield, *ap, *mp, *weapon;

int jacina_vjetra, promjena_vjetra;
double kut_vjetra, x_pomak_vjetra, y_pomak_vjetra;
int gen;
extern int initted;

void iscrtaj_reljef(int dio, int x_start, int x_end, int y_start, int y_end);
void ucitaj_teksture();
void ucitaj_kartu(int level);
void crtaj_tenk(int koji);
void crtaj_stranicu_tenka(double x_poz, double y_poz, double a1, double a2,
													double b1, double b2, double c1, double c2, int boja, int broj);
void uvodni_izbor();
void snimi_sliku();
void init();
void ispisi_sucelje(int map);
void crtaj_sucelje(int mod);
void data(void);
void iskon(void);
FILE *myopen (char *fname, char *mode);
void help(void);

void pocetne_vrijednosti(void);
void napravi_kartu(void);
int main_screen(int mod, int izbor);
void baci_poklon(void);
void crtaj_nebo(int startx, int endx);
void end_round(void);
void intr(void);
void inicijalizacija(void);
void ma_daj_okreni(int kamo);
void snimi_kartu(void);
void provjera_dodira(void);
void baci_smece(void);
void baci_projektil(void);
void end_turn(void);
void intro(void);
DATAFILE *load(char *name);
void unload(DATAFILE *df);
void si3dsound(DATAFILE *df);
void set_datafile_name();
int d_button(int msg, DIALOG *d, int c);
int d_credits(int msg, DIALOG *d, int c);
int d_screenshot(int msg, DIALOG *d, int c);
int d_option(int msg, DIALOG *d, int c);

#endif
